@@ -1,6 +1,7 @@
 from google.cloud import storage
 from airflow.models import Variable
 from datetime import datetime
+import os
 
 
 def load_gcs(project=None,
@@ -10,18 +11,23 @@ def load_gcs(project=None,
              processed=False):
 
     curr_date = datetime.now().strftime('%Y-%m-%d')
-
-    if processed:
-        filename = f'{table}-extract-{curr_date}-processed.csv'
-        state = 'processed'
-    else:
-        filename = f'{table}-extract-{curr_date}.csv'
-        state = 'raw'
-
     data_folder = Variable.get('data_folder')
     data_path = f'{data_folder}/{database}/{table}'
 
     client = storage.Client(project=project)
     bucket = client.get_bucket(gcs_bucket)
-    blob = bucket.blob(f'{state}/{database}/{table}/{filename}')
-    blob.upload_from_filename(filename=f'{data_path}/{filename}')
+
+    if processed:
+        filename = f'{table}-extract-{curr_date}-processed.parquet'
+
+        for file in os.listdir(f'{data_path}/{filename}'):
+            blob = bucket.blob(
+                f'processed/{database}/{table}/{filename}/{file}')
+            blob.upload_from_filename(
+                filename=f'{data_path}/{filename}/{file}')
+
+    else:
+        filename = f'{table}-extract-{curr_date}.csv'
+
+        blob = bucket.blob(f'raw/{database}/{table}/{filename}')
+        blob.upload_from_filename(filename=f'{data_path}/{filename}')
